summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>2008-08-31 16:53:16 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>2008-08-31 16:53:16 +0000
commit8c847312274dfc42a4a1a6a59d1d2c2033662d3f (patch)
tree2921e3bbf6a5cd2ce66b801a478b60813301c724
parent2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com> (diff)
downloadrtems-8c847312274dfc42a4a1a6a59d1d2c2033662d3f.tar.bz2
2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com>
* timer/timer.c: Rename timer driver methods to follow RTEMS programming conventions.
-rw-r--r--c/src/lib/libcpu/bfin/ChangeLog5
-rw-r--r--c/src/lib/libcpu/bfin/timer/timer.c22
2 files changed, 16 insertions, 11 deletions
diff --git a/c/src/lib/libcpu/bfin/ChangeLog b/c/src/lib/libcpu/bfin/ChangeLog
index 38ea9a0a49..167d0e991a 100644
--- a/c/src/lib/libcpu/bfin/ChangeLog
+++ b/c/src/lib/libcpu/bfin/ChangeLog
@@ -1,3 +1,8 @@
+2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com>
+
+ * timer/timer.c: Rename timer driver methods to follow RTEMS
+ programming conventions.
+
2008-08-18 Ralf Corsépius <ralf.corsepius@rtems.org>
* serial/twi.c: Remove unused var.
diff --git a/c/src/lib/libcpu/bfin/timer/timer.c b/c/src/lib/libcpu/bfin/timer/timer.c
index 703c265c06..dc6d85e81d 100644
--- a/c/src/lib/libcpu/bfin/timer/timer.c
+++ b/c/src/lib/libcpu/bfin/timer/timer.c
@@ -2,8 +2,8 @@
*
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
* Timer_initialize() and Read_timer(). Read_timer() usually returns
* the number of microseconds since Timer_initialize() exitted.
*
* Copyright (c) 2006 by Atos Automacao Industrial Ltda.
* written by Alain Schaefer <alain.schaefer@easc.ch>
@@ -22,14 +22,14 @@
uint32_t Timer_interrupts;
-rtems_boolean Timer_driver_Find_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
/*
- * Timer_initialize
+ * benchmark_timer_initialize
*
* Blackfin processor has a counter for clock cycles.
*/
-void Timer_initialize( void )
+void benchmark_timer_initialize( void )
{
/*reset counters*/
@@ -44,7 +44,7 @@ void Timer_initialize( void )
}
/*
* The following controls the behavior of Read_timer().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It
* is usually deducted from the number returned.
@@ -58,7 +58,7 @@ void Timer_initialize( void )
/* This value is in microseconds. */
#define LEAST_VALID 1 /* Don't trust a clicks value lower than this */
-int Read_timer( void )
+int benchmark_timer_read( void )
{
uint32_t clicks;
uint32_t total;
@@ -76,7 +76,7 @@ int Read_timer( void )
/* converting to microseconds */
total = clicks / (CCLK/1000000);
- if ( Timer_driver_Find_average_overhead == 1 )
+ if ( benchmark_timer_find_average_overhead == 1 )
return total; /* in XXX microsecond units */
else {
if ( total < LEAST_VALID )
@@ -93,14 +93,14 @@ int Read_timer( void )
* in Timing Test Suite.
*/
-rtems_status_code Empty_function( void )
+rtems_status_code benchmark_timer_empty_function( void )
{
return RTEMS_SUCCESSFUL;
}
-void Set_find_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
rtems_boolean find_flag
)
{
- Timer_driver_Find_average_overhead = find_flag;
+ benchmark_timer_find_average_overhead = find_flag;
}
@@ -2,8 +2,8 @@
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
- * Timer_initialize() and Read_timer(). Read_timer() usually returns
- * the number of microseconds since Timer_initialize() exitted.
+ * benchmark_timer_initialize() and benchmark_timer_read(). benchmark_timer_read() usually returns
+ * the number of microseconds since benchmark_timer_initialize() exitted.
*
* Copyright (c) 2006 by Atos Automacao Industrial Ltda.
@@ -44,7 +44,7 @@ void Timer_initialize( void )
}
/*
- * The following controls the behavior of Read_timer().
+ * The following controls the behavior of benchmark_timer_read().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It